@@ -73,7 +73,7 @@ class PycharmRemoteDebugger:
             run_module_as_main(self._code_args[0], alter_argv=True)
 
     def debug(self, timeout: int):
-        self._wait_for_debugger(timeout)
+        # self._wait_for_debugger(timeout)
         argv = list(sys.argv)
         log.info(f"Running {self._code_type.name.lower()} {self._code_args[0]} with args {self._code_args[1:]}")
 
@@ -82,7 +82,7 @@ class PycharmRemoteDebugger:
                 sys.argv = argv[argv.index("-m") + 1:]
                 self._run_module()
             elif self._code_type == CodeType.FILE:
-                sys.argv = argv[argv.index("-f") + 1:]
+                sys.argv = list(self._code_args)
                 self._run_file()
 
         sys.argv = argv
